Module data

Module data 

Types related to discrete scalar fields and sampling models.

Modules

field_iterator
Module with types and traits for structure agnostic iteration of field data.
sampler
Module with types used for sampling discrete fields.

Structs

DenseField
3-dimensional dense field for scalar values.
SparseField
3-dimensional sparse field for scalar values.
SparseFieldConfig
Configuration for the sparse field structure

Enums

BlockSize
Block size options for the nodes of a sparse field.