DenseField

Struct DenseField 

pub struct DenseField<T> { /* private fields */ }
3-dimensional dense field for scalar values.

A uniform grid representation that stores field values at every point in the sampling domain. The field geometry is defined by:

  • An origin point defining the minimum corner of the field
  • A uniform cell size for all dimensions
  • The number of points in x, y, and z directions

The field stores values in a contiguous array, providing efficient access and parallel processing capabilities. This representation is memory-intensive but offers fast random access and is well-suited for operations like smoothing and iso-surface extraction.

Note: This type should not be constructed directly. Instead, use ~DenseSampler to sample and extract a dense field from an implicit model.

Implementations

Source

impl<T> DenseField<T>

pub fn origin(&self) -> &Vec3<T>

Returns a reference to the origin point of the field as a Vec3<T>.

pub fn num_points(&self) -> usize

Returns the total number of points in the field as the product of points in each direction.

pub fn num_cells(&self) -> usize

Returns the total number of cells in the field as the product of cells in each direction. Note that the number of cells is one less than the number of points in each direction.

pub fn data(&self) -> &[T]

Returns a reference to the underlying data buffer as a slice.

Source

impl<T: Float> DenseField<T>

pub fn new(origin: Vec3<T>, cell_size: T, num_pts: Vec3i) -> Self

Create a new empty field.

Arguments
  • origin - The base of the field, and the first data location.
  • cell_size - The size of each cell in the field.
  • num_pts - Number of points in each direction.
Returns

A new DenseField initialized with zeros and the specified parameters.

pub fn from_bounds(bounds: BoundingBox<T>, cell_size: T) -> Self

Create a new empty field from bounds and a cell size.

Arguments
  • bounds - The extents of the field.
  • cell_size - The size of each cell in the field.
Returns

A new DenseField initialized with zeros and dimensions derived from the bounds and cell size.

pub fn from_data( origin: Vec3<T>, cell_size: T, num_pts: Vec3i, data: Vec<T>, ) -> Result<Self, ModelError>

Create a new field from a data buffer.

The size of the data buffer must match the specified point count.

Arguments
  • origin - The base of the field, and the first value location in space.
  • cell_size - The size of each cell in the field.
  • num_pts - Number of points in each direction.
  • data - The data buffer.
Returns

Ok with the generated DenseField if the data matches the point count, or Err if the data doesn’t match.

pub fn set_value(&mut self, index: usize, value: T)

Sets the value at a specific index in the data buffer.

Arguments
  • index - The 1D index in the data buffer.
  • value - The new value to set.
pub fn cell_size(&self) -> T

Returns the cell size of the field.

pub fn copy_data(&self) -> Vec<T>

Returns a copy of the data buffer in the field.

pub fn cell_corners(&self, i: usize, j: usize, k: usize) -> [Vec3<T>; 8]

Returns the vertex locations at the corners of the specified cell.

Arguments
  • i - Index in first direction.
  • j - Index in second direction.
  • k - Index in third direction.
Returns

An array of 8 Vec3<T> coordinates corresponding to the corners of the cell.

pub fn cell_values(&self, i: usize, j: usize, k: usize) -> [T; 8]

Returns the values at the corners of the specified cell.

Arguments
  • i - Index in first direction.
  • j - Index in second direction.
  • k - Index in third direction.
Returns

An array of 8 values corresponding to the corners of the cell.

pub fn threshold(&mut self, limit: T)

Assigns 0 to any point with an absolute value below the limit.

Arguments
  • limit - The limit threshold for non-zero values.
pub fn smooth(&mut self, factor: T, iterations: u32)

Performs a laplacian smoothing operation on the field data.

The value of each point will be updated based on the average of the adjacent points.

Arguments
  • factor - Interpolation value between the average of the adjacent points and the current value.
  • iterations - Number of successive smoothing iterations.
pub fn padding(&mut self, padding_value: T)

Applies padding to the field boundaries. All boundary points will be assigned a specific value.

This can be used to ensure open edges of a solid are capped at the bounds.

Arguments
  • padding_value - The value to assign to all boundary points.
Source

impl<T: ModelFloat + 'static> DenseField<T>

pub fn smooth_par(&mut self, factor: T, iterations: u32)

Performs a laplacian smoothing operation on the field data using parallel iteration.

The value of each point will be updated based on the average of the adjacent points. This is a parallel version of the smooth method.

Arguments
  • factor - Interpolation value between the average of the adjacent points and the current value.
  • iterations - Number of successive smoothing iterations.