Types related to discrete scalar fields and sampling models.
Modules
- field_
iterator - Module with types and traits for structure agnostic iteration of field data.
- sampler
- Module with types used for sampling discrete fields.
Structs
- Dense
Field - 3-dimensional dense field for scalar values.
- Sparse
Field - 3-dimensional sparse field for scalar values.
- Sparse
Field Config - Configuration for the sparse field structure
Enums
- Block
Size - Block size options for the nodes of a sparse field.