pub struct DenseField<T> { /* private fields */ }Expand description
3-dimensional dense field for scalar values.
A uniform grid representation that stores field values at every point in the sampling domain. The field geometry is defined by:
- An origin point defining the minimum corner of the field
- A uniform cell size for all dimensions
- The number of points in x, y, and z directions
The field stores values in a contiguous array, providing efficient access and parallel processing capabilities. This representation is memory-intensive but offers fast random access and is well-suited for operations like smoothing and iso-surface extraction.
Note: This type should not be constructed directly. Instead, use ~DenseSampler
to sample and extract a dense field from an implicit model.
Implementations
Sourceimpl<T> DenseField<T>
impl<T> DenseField<T>
Sourcepub fn origin(&self) -> &Vec3<T>
pub fn origin(&self) -> &Vec3<T>
Returns a reference to the origin point of the field as a Vec3<T>.
Sourcepub fn num_points(&self) -> usize
pub fn num_points(&self) -> usize
Returns the total number of points in the field as the product of points in each direction.
Sourceimpl<T: Float> DenseField<T>
impl<T: Float> DenseField<T>
Sourcepub fn new(origin: Vec3<T>, cell_size: T, num_pts: Vec3i) -> Self
pub fn new(origin: Vec3<T>, cell_size: T, num_pts: Vec3i) -> Self
Create a new empty field.
Arguments
origin- The base of the field, and the first data location.cell_size- The size of each cell in the field.num_pts- Number of points in each direction.
Returns
A new DenseField initialized with zeros and the specified parameters.
Sourcepub fn from_bounds(bounds: BoundingBox<T>, cell_size: T) -> Self
pub fn from_bounds(bounds: BoundingBox<T>, cell_size: T) -> Self
Create a new empty field from bounds and a cell size.
Arguments
bounds- The extents of the field.cell_size- The size of each cell in the field.
Returns
A new DenseField initialized with zeros and dimensions derived from the bounds and cell size.
Sourcepub fn from_data(
origin: Vec3<T>,
cell_size: T,
num_pts: Vec3i,
data: Vec<T>,
) -> Result<Self, ModelError>
pub fn from_data( origin: Vec3<T>, cell_size: T, num_pts: Vec3i, data: Vec<T>, ) -> Result<Self, ModelError>
Create a new field from a data buffer.
The size of the data buffer must match the specified point count.
Arguments
origin- The base of the field, and the first value location in space.cell_size- The size of each cell in the field.num_pts- Number of points in each direction.data- The data buffer.
Returns
Ok with the generated DenseField if the data matches the point count, or Err if the data doesn’t match.
Sourcepub fn set_value(&mut self, index: usize, value: T)
pub fn set_value(&mut self, index: usize, value: T)
Sets the value at a specific index in the data buffer.
Arguments
index- The 1D index in the data buffer.value- The new value to set.
Sourcepub fn threshold(&mut self, limit: T)
pub fn threshold(&mut self, limit: T)
Assigns 0 to any point with an absolute value below the limit.
Arguments
limit- The limit threshold for non-zero values.
Sourcepub fn smooth(&mut self, factor: T, iterations: u32)
pub fn smooth(&mut self, factor: T, iterations: u32)
Performs a laplacian smoothing operation on the field data.
The value of each point will be updated based on the average of the adjacent points.
Arguments
factor- Interpolation value between the average of the adjacent points and the current value.iterations- Number of successive smoothing iterations.
Sourceimpl<T: ModelFloat + 'static> DenseField<T>
impl<T: ModelFloat + 'static> DenseField<T>
Sourcepub fn smooth_par(&mut self, factor: T, iterations: u32)
pub fn smooth_par(&mut self, factor: T, iterations: u32)
Performs a laplacian smoothing operation on the field data using parallel iteration.
The value of each point will be updated based on the average of the adjacent points.
This is a parallel version of the smooth method.
Arguments
factor- Interpolation value between the average of the adjacent points and the current value.iterations- Number of successive smoothing iterations.